<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @since             1.0.0
 * @package           the7-re-installer
 *
 * @wordpress-plugin
 * Plugin Name:       The7 Re-installer
 * Description:       This plugin allow to re-install The7 theme with one click.
 * Version:           1.0.0
 * Author:            Dream-Theme
 * Author URI:        http://dream-theme.com/
 * Text Domain:       the7-re-installer
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class The7_Re_Installer {

	public function __construct() {
		add_action( 'after_setup_theme', array( $this, 'after_setup_theme' ) );
	}

	public function after_setup_theme() {
		if ( ! defined( 'THE7_VERSION' ) ) {
			return;
		}

		add_filter( 'site_transient_update_themes', array( $this, 'add_the7_update_info' ) );
		add_action( 'load-toplevel_page_the7-dashboard', array( $this, 'on_page_load_action' ) );
	}

	public function on_page_load_action() {
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
	}

	public function enqueue_scripts() {
		wp_enqueue_script( 'the7-re-installer-main', plugin_dir_url( __FILE__ ) . 'assets/the7-re-installer.js', array( 'jquery' ), false, true );

		ob_start();
		include 're-install-form.php';
		$form_html = ob_get_clean();

		wp_localize_script( 'the7-re-installer-main', 'the7RE', array(
			'formHTML' => $form_html,
		) );
	}

	public function add_the7_update_info( $transient ) {
		if ( ! isset( $_GET['the7-force-update'] ) || ! presscore_theme_is_activated() )  {
			return $transient;
		}

		$code = presscore_get_purchase_code();
		$the7_remote_api = new The7_Remote_API( $code );
		$theme_template = get_template();
		$transient->response[ $theme_template ] = array(
			'theme' => $theme_template,
			'new_version' => wp_get_theme( $theme_template )->get( 'Version' ),
			'url' => presscore_theme_update_get_changelog_url(),
			'package' => $the7_remote_api->get_theme_download_url(),
		);

		return $transient;
	}
}

new The7_Re_Installer();